/// File: main.dart
library jaguar.example.silly;

import 'dart:async';
import 'package:jaguar/jaguar.dart';
import 'package:sqljocky5/sqljocky.dart';
import 'package:sqljocky5/src/query/standard_data_packet.dart' as sj;

import 'package:jaguar_sqljocky/jaguar_sqljocky.dart';

@Api(path: '/api')
class SqlJockyExampleApi {
  @Get(path: '/post')
  // NOTE: This is how Postgre interceptor is wrapped
  // around a route.
  @WrapOne(#postgresDb)
  Future<Response<String>> mongoTest(Context ctx) async {
    // NOTE: This is how the opened postgre connection is injected
    // into routes
    final ConnectionPool db = ctx.getInput<ConnectionPool>(SqlJockyDb);
    await db.query("delete FROM posts");
    await db.query("insert into posts values (1, 'holla', 'jon')");

    StreamTransformer transformer = new StreamTransformer<sj.StandardDataPacket, Map>.fromHandlers(
        handleData: (sj.StandardDataPacket row, EventSink<Map> sink) {
          sink.add(row.fields);
        });
    Results stream = await db.query("select * from posts WHERE _id = 1");
    List<Map> map = await stream.transform(transformer).toList();

    return Response.json(map.first);
  }

  SqlJockyDb postgresDb(Context ctx) =>
      new SqlJockyDb('example', 'root', 'dart_jaguar');
}

Future<Null> main(List<String> args) async {
  final server = new Jaguar(multiThread: false);
  server.addApiReflected(new SqlJockyExampleApi());

  await server.serve();
}
