library jaguar_postgres.src.interceptor;

import 'dart:async';

import 'package:jaguar/jaguar.dart';
import 'package:sqljocky5/sqljocky.dart' as sj;

class SqlJockyDb extends Interceptor {
  /// ID for the interceptor instance
  final String id;

  /// MySQL hostname
  final String host;

  /// MySQL port
  final int port;

  /// MySQL username
  final String username;

  /// MySQL password
  final String password;

  /// MySQL database name
  final String databaseName;

  /// Pool size
  final int poolSize;

  /// The connection
  sj.ConnectionPool _conn;

  /// Returns the mongodb connection
  sj.ConnectionPool get conn => _conn;

  SqlJockyDb(this.databaseName, this.username, this.password,
      {this.host: 'localhost', this.port: 3306, this.poolSize: 10, this.id});

  Future<sj.ConnectionPool> pre(Context ctx) async {
    _conn = new sj.ConnectionPool(
        host: host,
        port: port,
        user: username,
        password: password,
        db: databaseName,
        max: poolSize);
    return _conn;
  }

  /// Closes the connection on route exit
  Null post(Context ctx, Response incoming) {
    _releaseConn();
    return null;
  }

  /// Closes the connection in case an exception occurs in route chain before
  /// [post] is called
  Future<Null> onException() async {
    _releaseConn();
  }

  /// Releases connection
  void _releaseConn() {
    _conn.closeConnectionsWhenNotInUse();
  }
}
